
#ifndef NTL_vec_ZZVec__H
#define NTL_vec_ZZVec__H

#include <NTL/vector.h>
#include <NTL/ZZVec.h>

NTL_OPEN_NNS

typedef Vec<ZZVec> vec_ZZVec;

NTL_CLOSE_NNS

#endif
